@@ -19,8 +19,8 @@ import uuid
 
 from lxml import etree
 
-from pm4py.objects.process_tree.process_tree import ProcessTree
-from pm4py.objects.process_tree.pt_operator import Operator
+from pm4py.objects.process_tree.obj import ProcessTree
+from pm4py.objects.process_tree.obj import Operator
 from pm4py.util import constants
 
 
