@@ -15,5 +15,7 @@
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
 from pm4py.statistics import traces, attributes, variants, start_activities, end_activities, util, \
-    sojourn_time, concurrent_activities, eventually_follows
-
+    sojourn_time, concurrent_activities, eventually_follows, rework
+import pkgutil
+if pkgutil.find_loader("intervaltree"):
+    from pm4py.statistics import overlap
