@@ -21,3 +21,6 @@ if pkgutil.find_loader("pulp"):
 
 if pkgutil.find_loader("ortools"):
     from pm4py.util.lp.variants import ortools_solver
+
+if pkgutil.find_loader("scipy"):
+    from pm4py.util.lp.variants import scipy_solver
