@@ -14,6 +14,11 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
+
+import deprecation
+
+
+@deprecation.deprecated("2.2.11", "3.0.0", details="removed")
 def check_pandas_ge_110():
     """
     Checks if the Pandas version is >= 1.1.0
@@ -28,6 +33,7 @@ def check_pandas_ge_110():
     return False
 
 
+@deprecation.deprecated("2.2.11", "3.0.0", details="removed")
 def check_pandas_ge_024():
     """
     Checks if the Pandas version is >= 0.24
